<!--
***
*** To avoid retyping too much info. Do a search and replace for the following:
*** um-common-oidc-client
-->
[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![MIT License][license-shield]][license-url]
![Build][build-shield]

<!-- PROJECT LOGO -->
<br />
<p align="center">
  <a href="https://github.com/EOEPCA/um-common-oidc-client">
  </a>

  <h3 align="center">EOEPCA-OIDC</h3>

  <p align="center">
    Python Library which provides an OIDC client
    <br />
    <a href="https://github.com/EOEPCA/um-common-oidc-client"><strong>Explore the docs</strong></a>
    .
    <a href="https://github.com/EOEPCA/um-common-oidc-client/issues">Report Bug</a>
    ·
    <a href="https://github.com/EOEPCA/um-common-oidc-client/issues">Request Feature</a>
  </p>
</p>

## Table of Contents

- [Table of Contents](#table-of-contents)
- [About The Project](#about-the-project)
  - [Built With](#built-with)
- [Getting Started](#getting-started)
  - [Prerequisites](#prerequisites)
  - [Installation](#installation)
  - [Testing](#testing)
- [Documentation & Usage](#documentation--usage)
- [Roadmap](#roadmap)
- [Contributing](#contributing)
- [License](#license)
- [Contact](#contact)
- [Acknowledgements](#acknowledgements)

## About The Project

### Built With

- [Python](https://www.python.org//)
- [PyTest](https://docs.pytest.org)
- [YAML](https://yaml.org/)
- [Travis CI](https://travis-ci.com/)

## Getting Started

This is an OpenID Connect Client implementation of end-user and client authentication

In order to upload into travis the new versions, just commit your work with TAG on it in any branch. 
This will allow other developers to release patches without merging into master branch.


To get a local copy up and running follow these simple steps.


### Prerequisites

This is an example of how to list things you need to use the software and how to install them.

- [Python 3](https://www.python.org//)
- [Pip](https://pip.pypa.io/en/stable/)

### Installation

Just download the library using pip

```sh

pip install eoepca_oidc

```

### Testing

```sh

pytest eoepca_oidc/tests

```

## Documentation & Usage

The component documentation can be found at https://eoepca.github.io/um-common-oidc-client/.

## Roadmap

See the [open issues](https://github.com/EOEPCA/um-common-oidc-client/issues) for a list of proposed features (and known issues).

## Contributing

Contributions are what make the open source community such an amazing place to be learn, inspire, and create. Any contributions you make are **greatly appreciated**.

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

## License

Distributed under the Apache-2.0 License. See `LICENSE` for more information.

## Contact

EOEPCA mailbox - eoepca.systemteam@telespazio.com

Project Link: [https://github.com/EOEPCA/um-common-oidc-client](https://github.com/EOEPCA/um-common-oidc-client)

## Acknowledgements

- README.md is based on [this template](https://github.com/othneildrew/Best-README-Template) by [Othneil Drew](https://github.com/othneildrew).


[contributors-shield]: https://img.shields.io/github/contributors/EOEPCA/um-common-oidc-client.svg?style=flat-square
[contributors-url]: https://github.com/EOEPCA/um-common-oidc-client/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/EOEPCA/um-common-oidc-client.svg?style=flat-square
[forks-url]: https://github.com/EOEPCA/um-common-oidc-client/network/members
[stars-shield]: https://img.shields.io/github/stars/EOEPCA/um-common-oidc-client.svg?style=flat-square
[stars-url]: https://github.com/EOEPCA/um-common-oidc-client/stargazers
[issues-shield]: https://img.shields.io/github/issues/EOEPCA/um-common-oidc-client.svg?style=flat-square
[issues-url]: https://github.com/EOEPCA/um-common-oidc-client/issues
[license-shield]: https://img.shields.io/github/license/EOEPCA/um-common-oidc-client.svg?style=flat-square
[license-url]: https://github.com/EOEPCA/um-common-oidc-client/blob/master/LICENSE
[build-shield]: https://www.travis-ci.com/EOEPCA/um-common-oidc-client.svg?branch=master
